useDynLib(hyper2, .registration=TRUE)

export("B")
export("GD")
export("GD_wong")
export("Ops.lsl")
export("accessor")
export("accessor3")
export("addL")
export("addL3")
export("advantage")
export("args2ordervec")
export("as.hyper3")
export("as.namedvectorlist")
export("as.ordertable")
export("as.suplist")
export("as.weight")
export("assign_lowlevel")
export("assign_lowlevel")
export("assigner")
export("assigner3")
export("attemptstable2supp3")
export("as.attemptstable")
export("rattemptstable")
export("balance")
export("brackets")
export("char2num")
export("character_to_number")
export("cheering3")
export("choose_losers")
export("choose_winners")
export("consistency")
export("dec")
export("den3")
export("dhyper2")
export("differentiate")
export("differentiate")
export("differentiate3")
export("dirichlet")
export("dirichlet3")
export("discard_flawed")
export("discard_flawed2")
export("e_to_p")
export("elimination")
export("equality")
export("equality3")
export("equalp")
export("equalp.test")
export("evaluate")
export("evaluate3")
export("fillup")
export("formula1_points_systems")
export("general_grouped_rank_likelihood")
export("ggrl")
export("goodbad")
export("gradient")
export("gradientn")
export("hessian")
export("hessian")
export("home_away")
export("home_away3")
export("home_draw_away3")
export("home_away_table")
export("hyper2")
export("hyper2")
export("hyper2")
export("hyper2")
export("hyper2")
export("hyper3")
export("hyper3_add")
export("hyper3_bw")
export("hyper3_equal")
export("hyper3_nv")
export("hyper3_m")
export("hyper3_prod")
export("hyper3_to_hyper2")
export("identityL")
export("identityL3")
export("inc")
export("indep")
export("is.dirichlet")
export("is.hyper2")
export("is.hyper3")
export("is_ok_hessian")
export("is_ok_weightedplayers")
export("is_valid_hyper2")
export("is_valid_hyper3")
export("keep_flawed")
export("knownp.test")
export("length")
export("like_series")
export("like_single_list")
export("list2nv")
export("loglik")
export("loglik")
export("loglik_lsl")
export("loglik_single")
export("loglik_single_redundant")
export("lsl")
export("lsl_add")
export("maxp")
export("maxp3")
export("maxp_lsl")
export("maxp_simplex")
export("maxp_single")
export("maxp_single2")
export("maxplist")
export("mean_hyper2")
export("mgf")
export("mult_grid")
export("multinom")
export("num3")
export("ordertable2points")
export("ordertable2supp")
export("ordertable2supp3")
export("ordertable_to_ranktable")
export("ordertrans")
export("ordertransplot")
export("ordervec2supp")
export("ordervec2supp3")
export("ordervec2supp3a")
export("overwrite")
export("overwrite3")
export("overwrite_lowlevel")
export("overwrite_lowlevel3")
export("p_to_e")
export("pair_grid")
export("pairwise")
export("pnames")
export("pnames<-")
export("pnames<-.hyper3")
export("pnv")
export("powers")
export("powers<-")
export("print")
export("probability")
export("profile_support_single")
export("profsupp")
export("psubs")
export("psubs_single")
export("pwa")
export("pwa3")
export("pwa3_single")
export("pwa23_single")
export("pwa23_multiple")
export("pwa23")
export("race")
export("ranktable_to_ordertable")
export("rankvec_likelihood")
export("rdirichlet")
export("rhyper2")
export("rhyper3")
export("rorder_single")
export("rp")
export("rpair3")
export("rp_unif")
export("rrace")
export("rrace3")
export("rracehyper3")
export("rrank")
export("rrankk")
export("rrank_single")
export("rwinner3")
export("saffy")
export("samep.test")
export("size")
export("setweight")
export("specificp.gt.test")
export("specificp.lt.test")
export("specificp.ne.test")
export("specificp.test")
export("sum.suplist")
export("suplist_add")
export("suplist_times_scalar")
export("swait")
export("tidy")
export("trial")
export("pick")
export("pass")
export("beats")
export("loses")
export("volley")
export("weights.hyper3")
export("white_draw3")
export("wikitable_to_ranktable")
export("zapweak")
export("zermelo")
export("zipf")
export(brackets)
export(hyper2_sum_hyper2)
export(pnames)
export(powers)
export(size)
export(as.ranktable)
export(is.ranktable)
export(suppfun)

export("ordertable")



import("Rdpack")
importFrom("Rdpack",reprompt)



importFrom(Rcpp, evalCpp)
importFrom("stats", "constrOptim","runif","rnorm","pchisq","rgamma","setNames")
importFrom("utils", "head")
importFrom("utils", "capture.output")
importFrom("partitions","perms")
importFrom("magrittr", "%>%", "%<>%","add","subtract")
importFrom("cubature", "adaptIntegrate")
importFrom("graphics", "abline", "par", "text","points")

importFrom("disordR","disord")
importFrom("disordR","hashcal")
importFrom("disordR","consistent")
importFrom("disordR","elements")
importFrom("disordR","is.disord")
importFrom("disordR","lapply")

importFrom("frab", "values")
importFrom("frab", "as.frab")
importFrom("frab", "as.namedvector")

importFrom("alabama","constrOptim.nl")

importFrom("calibrator","MH")

importFrom("crayon", "bold")

import(methods)

S3method(brackets,hyper2)
S3method(powers,hyper2)
S3method("powers<-",hyper2)
S3method(pnames,hyper2)
S3method(pnames,suplist)
S3method("pnames<-",hyper2)

S3method(print,ranktable)
S3method(print,ranktablesummary)
S3method(print,hyper2test)
S3method(print,attemptstable)
S3method(print,ordertable)
S3method(aperm,ordertable)

S3method("[", hyper2)
S3method("[<-", hyper2)

S3method(Ops,hyper2)
S3method(sum,hyper2)
S3method(print,hyper2)
S3method(head,hyper2)
S3method(length,hyper2)
S3method(summary,ranktable)

S3method(Ops,suplist)
S3method(sum,suplist)

S3method(Ops,lsl)

S3method("print",summary.hyper2)
S3method("summary",hyper2)

S3method(print,hyper3)
S3method("print",summary.hyper3)
S3method("summary",hyper3)

S3method("powers<-",hyper3)
S3method(Ops,hyper3)
S3method("sum",hyper3)
S3method("[", hyper3)
S3method("[<-", hyper3)
S3method("weights", hyper3)
S3method("pnames<-",hyper3)

S3method(as.vector, attemptstable)

S3method("as.ranktable",ordertable)
S3method("as.ranktable",ranktable)
S3method("as.ranktable",matrix)
S3method("[", ordertable)

S3method("suppfun", ranktable)
S3method("suppfun", ordertable)
S3method("suppfun", character)
S3method("suppfun", numeric)
S3method("suppfun", attemptstable)
